# Spring_Festival

> 2025春节彩蛋

> 创意来源 [2025蛇年春晚Logo震撼发布](https://www.bilibili.com/video/BV12PqhYwEe3)

## 如何安装

```
pip install Spring-Festival
```

## 如何使用

```
import chunjie

# 打开创意源视频
chunjie.watch_video()

# 打开创意源图片
chunjie.watch_image()
```
